/*
    Prototypes for the user/group functions
    
    Copyright (c) 2003 - 2004 Night Productions, by Darkshadow.  All Rights Reserved.
    http://homepage.mac.com/darkshadow02/developer.htm
    darkshadow02@mac.com
    
    May be used freely, but keep my name/copyright in the header.
    
    There is NO warranty of any kind, express or implied; use at your own risk.
    Responsibility for damages (if any) to anyone resulting from the use of this
    code rests entirely with the user.
    
    --> allUsers(void) - returns an array of all users on the machine.
    --> allGroups(void) - returns an array of all groups on the machine.
    --> normalUsers(void) - returns an array of all users whose UID is >= 500.
    --> adminUsers(void) - returns an array of all admin users.
    --> allUsersForGroup(NSString *name) - returns an array of all users for the given group.
    --> allUsersForGID(int groupId) - returns an array of all users for the given group.
    --> infoForAllUsers(void) - returns an array of dictionaries, one for each user, containing:
	    Key:		    Value:
	    User ID		    NSNumber containing uid of user
	    User Name		    NSString containing user's name
	    User Real Name	    NSString containing user's real name
	    User Home		    NSString containing user's home directory (path)
	    User Shell		    NSString containing user's default shell
	    User Group		    NSString containing name of the user's group
	    User Group ID	    NSNumber containing gid of user's group
	    --next two may be empty arrays--
	    User Other Groups       NSArray containing NSStrings of groups user belongs to
	    User Other Group IDs    NSArray containing NSNumbers of group IDs user belongs to
	    
	    *Note: there's a one-to-one correspondence between the last two arrays.
		   i.e. the first element in each array is pointing to the same group, etc, etc.
    
    --> realNameForUser(NSString *name) - returns an NSString with the given user's real name.
    --> realNameForUID(int userId) - returns an NSString with the given user's real name.
    --> infoForUID(int userId) - returns an NSDictionary containing user info (see above).
    --> infoForUser(NSString *name) - returns an NSDictionary containing user info.
*/


NSArray *   allUsers __P((void)),
	*   allGroups __P((void)),
	*   normalUsers __P((void)),
	*   adminUsers __P((void)),
	*   allUsersForGroup __P((NSString *)),
	*   allUsersForGID __P((int)),
	*   infoForAllUsers __P((void));

NSString *  realNameForUser __P((NSString *)),
	 *  realNameForUID __P((int));

NSDictionary *  infoForUID __P((int)),
	     *  infoForUser __P((NSString *));

